@@ -12,7 +12,7 @@
 
 import logging
 
-from keystoneauth1 import loading as kaloading
+from openstack import config
 from oslo_utils import importutils
 
 from ironicclient.common.i18n import _
@@ -21,40 +21,10 @@ from ironicclient import exc
 LOG = logging.getLogger(__name__)
 
 
-# TODO(vdrok): remove in Stein
-def convert_keystoneauth_opts(kwargs):
-    old_to_new_names = {
-        ('os_auth_token',): 'token',
-        ('os_username',): 'username',
-        ('os_password',): 'password',
-        ('os_auth_url',): 'auth_url',
-        ('os_project_id',): 'project_id',
-        ('os_project_name',): 'project_name',
-        ('os_tenant_id',): 'tenant_id',
-        ('os_tenant_name',): 'tenant_name',
-        ('os_region_name',): 'region_name',
-        ('os_user_domain_id',): 'user_domain_id',
-        ('os_user_domain_name',): 'user_domain_name',
-        ('os_project_domain_id',): 'project_domain_id',
-        ('os_project_domain_name',): 'project_domain_name',
-        ('os_service_type',): 'service_type',
-        ('os_endpoint_type',): 'interface',
-        ('ironic_url',): 'endpoint',
-        ('os_cacert', 'ca_file'): 'cafile',
-        ('os_cert', 'cert_file'): 'certfile',
-        ('os_key', 'key_file'): 'keyfile'
-    }
-    for olds, new in old_to_new_names.items():
-        for old in olds:
-            if kwargs.get(old):
-                LOG.warning('The argument "%s" passed to get_client is '
-                            'deprecated and will be removed in Stein release, '
-                            'please use "%s" instead.', old, new)
-                kwargs.setdefault(new, kwargs[old])
-
-
 def get_client(api_version, auth_type=None, os_ironic_api_version=None,
-               max_retries=None, retry_interval=None, **kwargs):
+               max_retries=None, retry_interval=None, session=None,
+               valid_interfaces=None, interface=None, service_type=None,
+               region_name=None, **kwargs):
     """Get an authenticated client, based on the credentials.
 
     :param api_version: the API version to use. Valid value: '1'.
@@ -63,6 +33,14 @@ def get_client(api_version, auth_type=None, os_ironic_api_version=None,
     :param max_retries: Maximum number of retries in case of conflict error
     :param retry_interval: Amount of time (in seconds) between retries in case
         of conflict error.
+    :param session: An existing keystoneauth session. Will be created from
+        kwargs if not provided.
+    :param valid_interfaces: List of valid endpoint interfaces to use if
+        the bare metal endpoint is not provided.
+    :param interface: An alias for valid_interfaces.
+    :param service_type: Bare metal endpoint service type.
+    :param region_name: Name of the region to use when searching the bare metal
+        endpoint.
     :param kwargs: all the other params that are passed to keystoneauth.
     """
     # TODO(TheJulia): At some point, we should consider possibly noting
@@ -70,7 +48,6 @@ def get_client(api_version, auth_type=None, os_ironic_api_version=None,
     # auto-negotiate to the greatest available version, however we do not
     # have the ability yet for a caller to cap the version, and will hold
     # off doing so until then.
-    convert_keystoneauth_opts(kwargs)
     if auth_type is None:
         if 'endpoint' in kwargs:
             if 'token' in kwargs:
@@ -81,31 +58,22 @@ def get_client(api_version, auth_type=None, os_ironic_api_version=None,
             auth_type = 'token'
         else:
             auth_type = 'password'
-    session = kwargs.get('session')
+
     if not session:
-        loader = kaloading.get_plugin_loader(auth_type)
-        loader_options = loader.get_options()
-        # option.name looks like 'project-name', while dest will be the actual
-        # argument name to which the value will be passed to (project_name)
-        auth_options = [o.dest for o in loader_options]
-        # Include deprecated names as well
-        auth_options.extend([d.dest for o in loader_options
-                             for d in o.deprecated])
-        auth_kwargs = {k: v for (k, v) in kwargs.items() if k in auth_options}
-        auth_plugin = loader.load_from_options(**auth_kwargs)
-        # Let keystoneauth do the necessary parameter conversions
-        session_loader = kaloading.session.Session()
-        session_opts = {k: v for (k, v) in kwargs.items() if k in
-                        [o.dest for o in session_loader.get_conf_options()]}
-        session = session_loader.load_from_options(auth=auth_plugin,
-                                                   **session_opts)
+        # TODO(dtantsur): consider flipping load_yaml_config to True to support
+        # the clouds.yaml format.
+        region = config.get_cloud_region(load_yaml_config=False,
+                                         load_envvars=False,
+                                         auth_type=auth_type,
+                                         **kwargs)
+        session = region.get_session()
 
     # Make sure we also pass the endpoint interface to the HTTP client.
     # NOTE(gyee/efried): 'interface' in ksa config is deprecated in favor of
     # 'valid_interfaces'. So, since the caller may be deriving kwargs from
     # conf, accept 'valid_interfaces' first. But keep support for 'interface',
     # in case the caller is deriving kwargs from, say, an existing Adapter.
-    interface = kwargs.get('valid_interfaces', kwargs.get('interface'))
+    interface = valid_interfaces or interface
 
     endpoint = kwargs.get('endpoint')
     if not endpoint:
@@ -116,9 +84,9 @@ def get_client(api_version, auth_type=None, os_ironic_api_version=None,
             # empty or None so there's no need to set it to publicURL
             # explicitly.
             endpoint = session.get_endpoint(
-                service_type=kwargs.get('service_type') or 'baremetal',
+                service_type=service_type or 'baremetal',
                 interface=interface,
-                region_name=kwargs.get('region_name')
+                region_name=region_name,
             )
         except Exception as e:
             raise exc.AmbiguousAuthSystem(
@@ -137,8 +105,22 @@ def get_client(api_version, auth_type=None, os_ironic_api_version=None,
     return Client(api_version, **ironicclient_kwargs)
 
 
-def Client(version, *args, **kwargs):
+def Client(version, endpoint_override=None, session=None, *args, **kwargs):
+    """Create a client of an appropriate version.
+
+    This call requires a session. If you want it to be created, use
+    ``get_client`` instead.
+
+    :param endpoint_override: A bare metal endpoint to use.
+    :param session: A keystoneauth session to use. This argument is actually
+        required and is marked optional only for backward compatibility.
+    :param args: Other arguments to pass to the HTTP client. Not recommended,
+        use kwargs instead.
+    :param kwargs: Other keyword arguments to pass to the HTTP client (e.g.
+        ``insecure``).
+    """
     module = importutils.import_versioned_module('ironicclient',
                                                  version, 'client')
     client_class = getattr(module, 'Client')
-    return client_class(*args, **kwargs)
+    return client_class(endpoint_override=endpoint_override, session=session,
+                        *args, **kwargs)
