@@ -14,20 +14,17 @@
 #    under the License.
 
 from distutils.version import StrictVersion
+import functools
+from http import client as http_client
 import logging
-import os
 import re
-import socket
-import ssl
 import textwrap
 import time
+from urllib import parse as urlparse
 
 from keystoneauth1 import adapter
 from keystoneauth1 import exceptions as kexc
 from oslo_serialization import jsonutils
-import six
-from six.moves import http_client
-import six.moves.urllib.parse as urlparse
 
 from ironicclient.common import filecache
 from ironicclient.common.i18n import _
@@ -40,7 +37,7 @@ from ironicclient import exc
 #             http://specs.openstack.org/openstack/ironic-specs/specs/kilo/api-microversions.html # noqa
 #             for full details.
 DEFAULT_VER = '1.9'
-LAST_KNOWN_API_VERSION = 58
+LAST_KNOWN_API_VERSION = 65
 LATEST_VERSION = '1.{}'.format(LAST_KNOWN_API_VERSION)
 
 LOG = logging.getLogger(__name__)
@@ -107,19 +104,23 @@ class VersionNegotiationMixin(object):
         :param resp: The response object from http request
         """
         def _query_server(conn):
-            if (self.os_ironic_api_version and
-                    not isinstance(self.os_ironic_api_version, list) and
-                    self.os_ironic_api_version != 'latest'):
+            if (self.os_ironic_api_version
+                    and not isinstance(self.os_ironic_api_version, list)
+                    and self.os_ironic_api_version != 'latest'):
                 base_version = ("/v%s" %
                                 str(self.os_ironic_api_version).split('.')[0])
             else:
                 base_version = API_VERSION
-            return self._make_simple_request(conn, 'GET', base_version)
+            # Raise exception on client or server error.
+            resp = self._make_simple_request(conn, 'GET', base_version)
+            if not resp.ok:
+                raise exc.from_response(resp, method='GET', url=base_version)
+            return resp
 
         version_overridden = False
 
-        if (resp and hasattr(resp, 'request') and
-                hasattr(resp.request, 'headers')):
+        if (resp and hasattr(resp, 'request')
+                and hasattr(resp.request, 'headers')):
             orig_hdr = resp.request.headers
             # Get the version of the client's last request and fallback
             # to the default for things like unit tests to not cause
@@ -128,8 +129,8 @@ class VersionNegotiationMixin(object):
                                        self.os_ironic_api_version)
         else:
             req_api_ver = self.os_ironic_api_version
-        if (resp and req_api_ver != self.os_ironic_api_version and
-                self.api_version_select_state == 'negotiated'):
+        if (resp and req_api_ver != self.os_ironic_api_version
+                and self.api_version_select_state == 'negotiated'):
             # If we have a non-standard api version on the request,
             # but we think we've negotiated, then the call was overridden.
             # We should report the error with the called version
@@ -172,10 +173,10 @@ class VersionNegotiationMixin(object):
         # be supported by the requested version.
         # TODO(TheJulia): We should break this method into several parts,
         # such as a sanity check/error method.
-        if ((self.api_version_select_state == 'user' and
-                not self._must_negotiate_version()) or
-                (self.api_version_select_state == 'negotiated' and
-                    version_overridden)):
+        if ((self.api_version_select_state == 'user'
+             and not self._must_negotiate_version())
+                or (self.api_version_select_state == 'negotiated'
+                    and version_overridden)):
             raise exc.UnsupportedVersion(textwrap.fill(
                 _("Requested API version %(req)s is not supported by the "
                   "server, client, or the requested operation is not "
@@ -192,7 +193,7 @@ class VersionNegotiationMixin(object):
                 % {'req': requested_version,
                    'min': min_ver, 'max': max_ver}))
 
-        if isinstance(requested_version, six.string_types):
+        if isinstance(requested_version, str):
             if requested_version == 'latest':
                 negotiated_ver = max_ver
             else:
@@ -262,9 +263,10 @@ class VersionNegotiationMixin(object):
         raise NotImplementedError()
 
     def _must_negotiate_version(self):
-        return (self.api_version_select_state == 'user' and
-                (self.os_ironic_api_version == 'latest' or
-                 isinstance(self.os_ironic_api_version, list)))
+        return (self.api_version_select_state == 'user'
+                and (self.os_ironic_api_version == 'latest'
+                     or isinstance(self.os_ironic_api_version, list)))
+
 
 _RETRY_EXCEPTIONS = (exc.Conflict, exc.ServiceUnavailable,
                      exc.ConnectionRefused, kexc.RetriableConnectionFailure)
@@ -272,7 +274,7 @@ _RETRY_EXCEPTIONS = (exc.Conflict, exc.ServiceUnavailable,
 
 def with_retries(func):
     """Wrapper for _http_request adding support for retries."""
-    @six.wraps(func)
+    @functools.wraps(func)
     def wrapper(self, url, method, **kwargs):
         if self.conflict_max_retries is None:
             self.conflict_max_retries = DEFAULT_MAX_RETRIES
@@ -299,70 +301,6 @@ def with_retries(func):
     return wrapper
 
 
-class VerifiedHTTPSConnection(six.moves.http_client.HTTPSConnection):
-    """httplib-compatible connection using client-side SSL authentication
-
-    :see http://code.activestate.com/recipes/
-            577548-https-httplib-client-connection-with-certificate-v/
-    """
-
-    def __init__(self, host, port, key_file=None, cert_file=None,
-                 ca_file=None, timeout=None, insecure=False):
-        six.moves.http_client.HTTPSConnection.__init__(self, host, port,
-                                                       key_file=key_file,
-                                                       cert_file=cert_file)
-        self.key_file = key_file
-        self.cert_file = cert_file
-        if ca_file is not None:
-            self.ca_file = ca_file
-        else:
-            self.ca_file = self.get_system_ca_file()
-        self.timeout = timeout
-        self.insecure = insecure
-
-    def connect(self):
-        """Connect to a host on a given (SSL) port.
-
-        If ca_file is pointing somewhere, use it to check Server Certificate.
-
-        Redefined/copied and extended from httplib.py:1105 (Python 2.6.x).
-        This is needed to pass cert_reqs=ssl.CERT_REQUIRED as parameter to
-        ssl.wrap_socket(), which forces SSL to check server certificate against
-        our client certificate.
-        """
-        sock = socket.create_connection((self.host, self.port), self.timeout)
-
-        if self._tunnel_host:
-            self.sock = sock
-            self._tunnel()
-
-        if self.insecure is True:
-            kwargs = {'cert_reqs': ssl.CERT_NONE}
-        else:
-            kwargs = {'cert_reqs': ssl.CERT_REQUIRED, 'ca_certs': self.ca_file}
-
-        if self.cert_file:
-            kwargs['certfile'] = self.cert_file
-            if self.key_file:
-                kwargs['keyfile'] = self.key_file
-
-        self.sock = ssl.wrap_socket(sock, **kwargs)
-
-    @staticmethod
-    def get_system_ca_file():
-        """Return path to system default CA file."""
-        # Standard CA file locations for Debian/Ubuntu, RedHat/Fedora,
-        # Suse, FreeBSD/OpenBSD
-        ca_path = ['/etc/ssl/certs/ca-certificates.crt',
-                   '/etc/pki/tls/certs/ca-bundle.crt',
-                   '/etc/ssl/ca-bundle.pem',
-                   '/etc/ssl/cert.pem']
-        for ca in ca_path:
-            if os.path.exists(ca):
-                return ca
-        return None
-
-
 class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
     """HTTP client based on Keystone client session."""
 
@@ -376,7 +314,7 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         self.api_version_select_state = api_version_select_state
         self.conflict_max_retries = max_retries
         self.conflict_retry_interval = retry_interval
-        if isinstance(kwargs.get('endpoint_override'), six.string_types):
+        if isinstance(kwargs.get('endpoint_override'), str):
             kwargs['endpoint_override'] = _trim_endpoint_api_version(
                 kwargs['endpoint_override'])
 
@@ -417,7 +355,7 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
 
         kwargs.setdefault('user_agent', USER_AGENT)
         kwargs.setdefault('auth', self.auth)
-        if isinstance(self.endpoint_override, six.string_types):
+        if isinstance(self.endpoint_override, str):
             kwargs.setdefault('endpoint_override', self.endpoint_override)
 
         if getattr(self, 'os_ironic_api_version', None):
@@ -461,8 +399,8 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         body = resp.content
         content_type = resp.headers.get('content-type', None)
         status = resp.status_code
-        if (status in (http_client.NO_CONTENT, http_client.RESET_CONTENT) or
-                content_type is None):
+        if (status in (http_client.NO_CONTENT, http_client.RESET_CONTENT)
+                or content_type is None):
             return resp, list()
         if 'application/json' in content_type:
             try:
