@@ -145,7 +145,7 @@ class TestChassisDelete(TestChassis):
 
         # Set expected values
         args = [uuid1, uuid2]
-        self.baremetal_mock.chassis.delete.has_calls(
+        self.baremetal_mock.chassis.delete.assert_has_calls(
             [mock.call(x) for x in args]
         )
         self.assertEqual(2, self.baremetal_mock.chassis.delete.call_count)
@@ -167,7 +167,7 @@ class TestChassisDelete(TestChassis):
 
         # Set expected values
         args = [uuid1, uuid2]
-        self.baremetal_mock.chassis.delete.has_calls(
+        self.baremetal_mock.chassis.delete.assert_has_calls(
             [mock.call(x) for x in args]
         )
         self.assertEqual(2, self.baremetal_mock.chassis.delete.call_count)
@@ -352,6 +352,15 @@ class TestChassisSet(TestChassis):
                           self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_chassis_set_no_property(self):
+        uuid = baremetal_fakes.baremetal_chassis_uuid
+        arglist = [uuid]
+        verifylist = [('chassis', uuid)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.assertFalse(self.baremetal_mock.chassis.update.called)
+
     def test_chassis_set_description(self):
         description = 'new description'
         uuid = baremetal_fakes.baremetal_chassis_uuid
@@ -532,6 +541,15 @@ class TestChassisUnset(TestChassis):
                           self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_chassis_unset_no_property(self):
+        uuid = baremetal_fakes.baremetal_chassis_uuid
+        arglist = [uuid]
+        verifylist = [('chassis', uuid)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.assertFalse(self.baremetal_mock.chassis.update.called)
+
     def test_chassis_unset_description(self):
         uuid = baremetal_fakes.baremetal_chassis_uuid
         arglist = [
