@@ -17,7 +17,6 @@ import tempfile
 import time
 
 import mock
-import six
 import testtools
 from testtools.matchers import HasLength
 
@@ -28,9 +27,6 @@ from ironicclient.v1 import node
 from ironicclient.v1 import volume_connector
 from ironicclient.v1 import volume_target
 
-if six.PY3:
-    import io
-    file = io.BytesIO
 
 NODE1 = {'uuid': '66666666-7777-8888-9999-000000000000',
          'chassis_uuid': 'aaaaaaaa-1111-bbbb-2222-cccccccccccc',
@@ -51,7 +47,10 @@ NODE2 = {'uuid': '66666666-7777-8888-9999-111111111111',
          'driver_info': {'user': 'foo', 'password': 'bar'},
          'properties': {'num_cpu': 4},
          'resource_class': 'bar',
-         'extra': {}}
+         'extra': {},
+         'owner': '33333333-2222-1111-0000-111111111111',
+         'retired': True,
+         'lessee': '77777777-8888-5555-2222-999999999999'}
 PORT = {'uuid': '11111111-2222-3333-4444-555555555555',
         'node_uuid': '66666666-7777-8888-9999-000000000000',
         'address': 'AA:AA:AA:AA:AA:AA',
@@ -173,6 +172,20 @@ fake_responses = {
             {"nodes": [NODE2]},
         )
     },
+    '/v1/nodes/?retired=False':
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE1]},
+        )
+    },
+    '/v1/nodes/?retired=True':
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE2]},
+        )
+    },
     '/v1/nodes/?associated=True&maintenance=True':
     {
         'GET': (
@@ -180,6 +193,13 @@ fake_responses = {
             {"nodes": [NODE2]},
         )
     },
+    '/v1/nodes/?associated=True&retired=True':
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE2]},
+        )
+    },
     '/v1/nodes/?provision_state=available':
     {
         'GET': (
@@ -187,6 +207,20 @@ fake_responses = {
             {"nodes": [NODE1]},
         )
     },
+    '/v1/nodes/?owner=%s' % NODE2['owner']:
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE2]},
+        )
+    },
+    '/v1/nodes/?lessee=%s' % NODE2['lessee']:
+    {
+        'GET': (
+            {},
+            {"nodes": [NODE2]},
+        )
+    },
     '/v1/nodes/?driver=fake':
     {
         'GET': (
@@ -341,7 +375,8 @@ fake_responses = {
             {},
             {"connectors": [CONNECTOR]},
         ),
-    },    '/v1/nodes/%s/volume/targets' % NODE1['uuid']:
+    },
+    '/v1/nodes/%s/volume/targets' % NODE1['uuid']:
     {
         'GET': (
             {},
@@ -794,6 +829,24 @@ class NodeManagerTest(testtools.TestCase):
         self.assertThat(nodes, HasLength(1))
         self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
 
+    def test_node_list_retired(self):
+        nodes = self.mgr.list(retired=True)
+        expect = [
+            ('GET', '/v1/nodes/?retired=True', {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
+
+    def test_node_list_not_retired(self):
+        nodes = self.mgr.list(retired=False)
+        expect = [
+            ('GET', '/v1/nodes/?retired=False', {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE1['uuid'], getattr(nodes[0], 'uuid'))
+
     def test_node_list_provision_state(self):
         nodes = self.mgr.list(provision_state="available")
         expect = [
@@ -803,6 +856,24 @@ class NodeManagerTest(testtools.TestCase):
         self.assertThat(nodes, HasLength(1))
         self.assertEqual(NODE1['uuid'], getattr(nodes[0], 'uuid'))
 
+    def test_node_list_owner(self):
+        nodes = self.mgr.list(owner=NODE2['owner'])
+        expect = [
+            ('GET', '/v1/nodes/?owner=%s' % NODE2['owner'], {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE2['owner'], getattr(nodes[0], 'owner'))
+
+    def test_node_list_lessee(self):
+        nodes = self.mgr.list(lessee=NODE2['lessee'])
+        expect = [
+            ('GET', '/v1/nodes/?lessee=%s' % NODE2['lessee'], {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE2['lessee'], getattr(nodes[0], 'lessee'))
+
     def test_node_list_provision_state_fail(self):
         self.assertRaises(KeyError, self.mgr.list,
                           provision_state="test")
@@ -862,6 +933,15 @@ class NodeManagerTest(testtools.TestCase):
         self.assertThat(nodes, HasLength(1))
         self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
 
+    def test_node_list_associated_and_retired(self):
+        nodes = self.mgr.list(associated=True, retired=True)
+        expect = [
+            ('GET', '/v1/nodes/?associated=True&retired=True', {}, None),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertThat(nodes, HasLength(1))
+        self.assertEqual(NODE2['uuid'], getattr(nodes[0], 'uuid'))
+
     def test_node_list_with_conductor(self):
         nodes = self.mgr.list(conductor='fake-conductor')
         expect = [
@@ -1532,7 +1612,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_id': 'node_uuid',
             'method': 'method',
             'args': vendor_passthru_args
-            }
+        }
 
         final_path = 'node_uuid/vendor_passthru/method'
         for http_method in ('POST', 'PUT', 'PATCH'):
@@ -1549,7 +1629,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_id': 'node_uuid',
             'method': 'method',
             'http_method': 'GET',
-            }
+        }
 
         final_path = 'node_uuid/vendor_passthru/method'
         self.mgr.vendor_passthru(**kwargs)
@@ -1561,7 +1641,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_id': 'node_uuid',
             'method': 'method',
             'http_method': 'DELETE',
-            }
+        }
 
         final_path = 'node_uuid/vendor_passthru/method'
         self.mgr.vendor_passthru(**kwargs)
@@ -1573,7 +1653,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_id': 'node_uuid',
             'method': 'method',
             'http_method': 'UNKNOWN',
-            }
+        }
         self.assertRaises(exc.InvalidAttribute, self.mgr.vendor_passthru,
                           **kwargs)
 
@@ -1581,7 +1661,7 @@ class NodeManagerTest(testtools.TestCase):
     def test_vif_list(self, _list_mock):
         kwargs = {
             'node_ident': NODE1['uuid'],
-            }
+        }
 
         final_path = '/v1/nodes/%s/vifs' % NODE1['uuid']
         self.mgr.vif_list(**kwargs)
@@ -1592,7 +1672,7 @@ class NodeManagerTest(testtools.TestCase):
         kwargs = {
             'node_ident': NODE1['uuid'],
             'vif_id': 'vif_id',
-            }
+        }
 
         final_path = '%s/vifs' % NODE1['uuid']
         self.mgr.vif_attach(**kwargs)
@@ -1605,7 +1685,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_ident': NODE1['uuid'],
             'vif_id': 'vif_id',
             'foo': 'bar',
-            }
+        }
 
         final_path = '%s/vifs' % NODE1['uuid']
         self.mgr.vif_attach(**kwargs)
@@ -1620,7 +1700,7 @@ class NodeManagerTest(testtools.TestCase):
             'node_ident': NODE1['uuid'],
             'vif_id': 'vif_id',
             'id': 'bar',
-            }
+        }
         self.assertRaises(
             exc.InvalidAttribute,
             self.mgr.vif_attach, **kwargs)
@@ -1630,7 +1710,7 @@ class NodeManagerTest(testtools.TestCase):
         kwargs = {
             'node_ident': NODE1['uuid'],
             'vif_id': 'vif_id',
-            }
+        }
 
         final_path = '%s/vifs/vif_id' % NODE1['uuid']
         self.mgr.vif_detach(**kwargs)
