@@ -56,11 +56,12 @@ class NodeManager(base.CreateManager):
                             'automated_clean']
     _resource_name = 'nodes'
 
-    def list(self, associated=None, maintenance=None, marker=None, limit=None,
-             detail=False, sort_key=None, sort_dir=None, fields=None,
-             provision_state=None, driver=None, resource_class=None,
-             chassis=None, fault=None, os_ironic_api_version=None,
-             conductor_group=None, conductor=None, owner=None):
+    def list(self, associated=None, maintenance=None, marker=None,
+             limit=None, detail=False, sort_key=None, sort_dir=None,
+             fields=None, provision_state=None, driver=None,
+             resource_class=None, chassis=None, fault=None,
+             os_ironic_api_version=None, conductor_group=None,
+             conductor=None, owner=None, retired=None, lessee=None):
         """Retrieve a list of nodes.
 
         :param associated: Optional. Either a Boolean or a string
@@ -72,6 +73,9 @@ class NodeManager(base.CreateManager):
                             to return nodes in maintenance mode (True or
                             "True"), or not in maintenance mode (False or
                             "False").
+        :param retired: Optional. Either a Boolean or a string representation
+                        of a Boolean that indicates whether to return retired
+                        nodes (True or "True").
         :param provision_state: Optional. String value to get only nodes in
                                 that provision state.
         :param marker: Optional, the UUID of a node, eg the last
@@ -118,6 +122,8 @@ class NodeManager(base.CreateManager):
                           mapped to the given conductor.
         :param owner: Optional. String value to get only nodes
                           mapped to a specific owner.
+        :param lessee: Optional. String value to get only nodes
+                          mapped to a specific lessee.
 
         :returns: A list of nodes.
 
@@ -135,6 +141,8 @@ class NodeManager(base.CreateManager):
             filters.append('associated=%s' % associated)
         if maintenance is not None:
             filters.append('maintenance=%s' % maintenance)
+        if retired is not None:
+            filters.append('retired=%s' % retired)
         if fault is not None:
             filters.append('fault=%s' % fault)
         if provision_state is not None:
@@ -151,6 +159,8 @@ class NodeManager(base.CreateManager):
             filters.append('conductor=%s' % conductor)
         if owner is not None:
             filters.append('owner=%s' % owner)
+        if lessee is not None:
+            filters.append('lessee=%s' % lessee)
 
         path = ''
         if detail:
@@ -705,8 +715,8 @@ class NodeManager(base.CreateManager):
                 return
 
             # Note that if expected_state == 'error' we still succeed
-            if (node.provision_state == 'error' or
-                    node.provision_state.endswith(' failed')):
+            if (node.provision_state == 'error'
+                    or node.provision_state.endswith(' failed')):
                 raise exc.StateTransitionFailed(
                     _('Node %(node)s failed to reach state %(state)s. '
                       'It\'s in state %(actual)s, and has error: %(error)s') %
